const serverUrl = 'https://pushnotify.i-as.dev';

async function checkSubscriptionStatus() {
  const subscription = await navigator.serviceWorker.ready.then(registration => {
    return registration.pushManager.getSubscription();
  });

  return subscription !== null;
}

async function sendNotification() {
  try {
    const isSubscribed = await checkSubscriptionStatus();

    if (isSubscribed) {
      const notificationData = {
        domain: window.location.host,
        title: document.getElementById('notificationTitle').value,
        message: document.getElementById('notificationMessage').value,
        imageUrl: document.getElementById('notificationImageUrl').value,
        url: document.getElementById('notificationUrl').value
      };

      console.log('Sending notification data:', notificationData);

      const response = await fetch(`${serverUrl}/api/notification`, {
        method: 'POST',
        body: JSON.stringify(notificationData),
        headers: {
          'Content-Type': 'application/json'
        }
      });

      const data = await response.json();

      if (response.ok) {
        console.log('Notification sent successfully');
      } else {
        console.error('Failed to send notification:', data);
      }
    } else {
      console.log('User is not subscribed. Notification not sent.');
    }
  } catch (error) {
    console.error('Error sending notification:', error);
  }
}

document.addEventListener('DOMContentLoaded', function () {
  document.getElementById('sendNotificationButton').addEventListener('click', sendNotification);
});
