const serverUrl = 'https://pushnotify.i-as.dev';
let publicPushNotifyKey = '';

if ('serviceWorker' in navigator) {
    navigator.serviceWorker.register('./service-worker.js')
    .then(function (registration) {
        console.log('Service Worker Registered Successfully:', registration.scope);
        return fetchConnection().then(() => subscribeUser(registration));
    })
    .catch(function (error) {
        console.error('Service Worker registration failed:', error);
    });
}

function urlBase64ToUint8Array(base64String) {
    const padding = '='.repeat((4 - base64String.length % 4) % 4);
    const base64 = (base64String + padding)
    .replace(/-/g, '+')
    .replace(/_/g, '/');
    const rawData = window.atob(base64);
    const outputArray = new Uint8Array(rawData.length);
    for (let i = 0; i < rawData.length; ++i) {
        outputArray[i] = rawData.charCodeAt(i);
    }
    return outputArray;
}

function fetchConnection() {
    return fetch(`${serverUrl}/api/connection`)
    .then(response => response.json())
    .then(data => {
        publicPushNotifyKey = data.publicKey;
    })
    .catch(error => {
        console.error('Failed to connection:', error);
    });
}

function subscribeUser(registration) {
    return registration.pushManager.getSubscription()
    .then(function (subscription) {
        if (subscription) {
            console.log('User is already subscribed');
            return subscription;
        }

        const applicationServerKey = urlBase64ToUint8Array(publicPushNotifyKey);
        return registration.pushManager.subscribe({
            userVisibleOnly: true,
            applicationServerKey: applicationServerKey
        });
    })
    .then(function (subscription) {
        console.log('Subscription successful');
        return fetch(`${serverUrl}/api/subscribe`, {
            method: 'POST',
            body: JSON.stringify({
                domain: window.location.host,
                subscription: subscription
            }),
            headers: {
                'Content-Type': 'application/json'
            }
        });
    })
    .catch(function (error) {
        console.error('Subscription failed:', error);
    });
}

function checkSubscriptionStatus(callback) {
    navigator.serviceWorker.ready.then(function (registration) {
        return registration.pushManager.getSubscription()
        .then(function (subscription) {
            if (subscription) {
                console.log('User is subscribed');
                callback(true);
            } else {
                console.log('User is not subscribed');
                callback(false);
            }
        })
        .catch(function (error) {
            console.error('Error checking subscription status:', error);
            callback(false);
        });
    });
}

function unsubscribeUser() {
    navigator.serviceWorker.ready.then(function (registration) {
        return registration.pushManager.getSubscription()
        .then(function (subscription) {
            if (subscription) {
                return fetch(`${serverUrl}/api/unsubscribe`, {
                    method: 'POST',
                    body: JSON.stringify({
                        domain: window.location.host,
                        subscription: subscription
                    }),
                    headers: {
                        'Content-Type': 'application/json'
                    }
                })
                .then(() => subscription.unsubscribe())
                .then(() => console.log('Unsubscribed successfully'))
                .catch(err => console.error('Error during unsubscribe:', err));
            } else {
                console.log('No subscription found');
            }
        });
    });
}

document.getElementById('subscribeButton').addEventListener('click', () => {
    navigator.serviceWorker.ready.then(registration => subscribeUser(registration));
});

document.getElementById('unsubscribeButton').addEventListener('click', () => {
    unsubscribeUser();
});
